
DEFAULT_VINS_CFG_FILE_TPL = """
{
  "app": {
    "comment": "add your comment here",
    "vins_url": "%(vins_url)s",
    "api_key": "%(api_key)s",
    "tokens": {
      "admin": "%(token_admin)s",
      "client": "%(token_client)s"
    },
    "app_id": "%(app_id)s"
  },
  "dm": {
    "engine": "form_filler",
    "intents": [{
      "intent": "dont_understand",
      "path": "intents/dont_understand.js"
    }, {
      "intent": "greeting",
      "path": "intents/greeting.js"
    }, {
      "intent": "thanks",
      "path": "intents/thanks.js"
    }, {
      "intent": "goodbye",
      "path": "intents/goodbye.js"
    }, {
      "intent": "how_are_you",
      "path": "intents/how_are_you.js"
    }]
  },
  "nlu": {
    "engine": "fuzzy",
    "intents": [{
      "intent": "greeting",
      "path": "nlu/greeting.nlu"
    }, {
      "intent": "thanks",
      "path": "nlu/thanks.nlu"
    }, {
      "intent": "goodbye",
      "path": "nlu/goodbye.nlu"
    }, {
      "intent": "how_are_you",
      "path": "nlu/how_are_you.nlu"
    }]
  },
  "nlg": {
    "engine": "fuzzy",
    "intents": [{
      "intent": "dont_understand",
      "path": "nlg/dont_understand.nlg"
    }, {
      "intent": "greeting",
      "path": "nlg/greeting.nlg"
    }, {
      "intent": "thanks",
      "path": "nlg/thanks.nlg"
    }, {
      "intent": "goodbye",
      "path": "nlg/goodbye.nlg"
    }, {
      "intent": "how_are_you",
      "path": "nlg/how_are_you.nlg"
    }]
  }
}
"""

DEFAULT_INTENT_DONT_UNDERSTAND_TPL = """
{
    "form": "dont_understand",
    "comment": "если команда не понятна, то активируется этот intent",
    "events": [
        {
            "event": "submit",
            "handler": "nlg",
            "phrase_id": "i_dont_undestand_you"
        }
    ],
    "slots": [
        {
          "slot": "utterance",
          "type": "string",
          "optional": true,
          "events": []
        }
    ]
}
"""

DEFAULT_INTENT_GOODBYE_TPL = """
{
    "form": "goodbye",
    "comment": "клиент прощается",
    "events": [
        {
            "event": "submit",
            "handler": "nlg",
            "phrase_id": "goodbye"
        }
    ]
}
"""

DEFAULT_INTENT_GREETING_TPL = """
{
    "form": "greeting",
    "comment": "клиент здоровается",
    "events": [
        {
            "event": "submit",
            "handler": "nlg",
            "phrase_id": "greeting"
        }
    ]
}
"""

DEFAULT_INTENT_HOW_ARE_YOU_TPL = """
{
    "form": "how_are_you",
    "comment": "клиент спрашивает как дела?",
    "events": [
        {
            "event": "submit",
            "handler": "nlg",
            "phrase_id": "fine_thanks"
        }
    ]
}
"""

DEFAULT_INTENT_THANKS_TPL = """
{
    "form": "thanks",
    "comment": "клиент благодарит",
    "events": [
        {
            "event": "submit",
            "handler": "nlg",
            "phrase_id": "you_are_wellcome"
        }
    ]
}

"""

DEFAULT_NLG_DONT_UNDERSTAND_TPL = """
[i_dont_undestand_you]
я тебя не понимаю
повтори пожалуйста
Что ты имеешь ввиду?
Прости, не понимаю
я тебя не понимаю, ты сказал 'aaa'(utterance)
"""

DEFAULT_NLG_GOODBYE_TPL = """
[goodbye]
пока
удачи!
всего доброго!
"""

DEFAULT_NLG_GREETING_TPL = """
[greeting]
привет
приветик
здарова
"""

DEFAULT_NLG_HOW_ARE_YOU_TPL = """
[fine_thanks]
спасибо всё хорошо
у меня всё прекрасно
замечательно
"""

DEFAULT_NLG_THANKS_TPL = """
[you_are_wellcome]
всегда пожалуйста
всегда рада помочь
не стоит благодаростей
не, не надо. не люблю похвалу
это моя работа. служить тебе
"""

DEFAULT_NLU_GOODBYE_TPL = """
# - классификация -

пока
покеда
покедова
спасибо пока
"""

DEFAULT_NLU_GREETING_TPL = """
# - классификация -

привет
приветик
здорова
хай
"""

DEFAULT_NLU_HOW_ARE_YOU_TPL = """
# - классификация -

как дела
как делишки
"""

DEFAULT_NLU_THANKS_TPL = """
# - классификация -

спасиб
спасибо
благодарю
ты лучший
ты лучшая
"""

NEW_INTENT_TPL = """
{
  "form": "%(intent)s",
  "events": [],
  "slots": []
}
"""

NEW_INTENT_NLU_TPL = """
# закажи мне такси
# мне нужна тачка
# отвезите меня
#
# закажи мне такси на '8 утра'(when)
# мне нужна машина на 'улицу маршала неделина дом 6'(location_from) на 7 утра(when)
"""

NEW_INTENT_NLG_TPL = """
# [order_taxi_finished_successfully]
# заказ сформирован
# заказ создан. спасибо что воспользовались сервисом такси!
#
# [get_taxi_status]
# к вам едет 'жёлтый'(color) 'citroen'(brand) гос. номер 'a345mp197'(number)
# ожидайте машину 'жёлтый'(color) 'citroen'(brand) гос. номер 'a345mp197'(number)
"""





import json
import logging
import os

import click

from vins_cli.exceptions import VinsCfgParseError
import vins_cli.settings as settings
from vins_cli.default import NEW_INTENT_TPL
from vins_cli.default import NEW_INTENT_NLU_TPL
from vins_cli.default import NEW_INTENT_NLG_TPL


def command(intent_name):
    click.secho('Creating intent %s...' % intent_name, fg='blue')

    if not os.path.exists(settings.VINS_CFG_PATH):
        raise VinsCfgParseError(
            "file %s does not exist" % settings.VINS_CFG_PATH
        )

    with open(settings.VINS_CFG_PATH, "r") as f:
        cfg = json.load(f)

        # - checking app section -

        if cfg.get('app') is None:
            raise VinsCfgParseError('"app" section is missing')

        api_key = cfg['app'].get('api_key')
        vins_url = cfg['app'].get('vins_url')
        app_id = cfg['app'].get('app_id')

        if api_key is None:
            raise VinsCfgParseError('"api_key" is missing')
        if vins_url is None:
            raise VinsCfgParseError('"vins_url" is missing')
        if app_id is None:
            raise VinsCfgParseError('"app_id" is missing')

        intent_path = "intents/%s.js" % intent_name
        nlg_path = "nlg/%s.nlg" % intent_name
        nlu_path = "nlu/%s.nlu" % intent_name

        click.secho('Creating files...', fg='blue')

        with open(intent_path, "w") as f_intent:
            f_intent.write(NEW_INTENT_TPL % dict(intent=intent_name))
        with open(nlg_path, "w") as f_nlg:
            f_nlg.write(NEW_INTENT_NLG_TPL)
        with open(nlu_path, "w") as f_nlu:
            f_nlu.write(NEW_INTENT_NLU_TPL)

        click.secho('Registering files into Vinsfile...', fg='blue')

        cfg['dm']['intents'].append({
            "intent": intent_name,
            "path": intent_path
        })
        cfg['nlg']['intents'].append({
            "intent": intent_name,
            "path": nlg_path
        })
        cfg['nlu']['intents'].append({
            "intent": intent_name,
            "path": nlu_path
        })

    with open(settings.VINS_CFG_PATH, "w") as f:
        json.dump(cfg, f, indent=2, ensure_ascii=False)

    click.secho('Done!', fg='green')



#!/usr/bin/env python2.7
# vim: set fileencoding=utf-8

import click

from vins_cli.exceptions import VinsCfgParseError


@click.group()
def main():
    """Voice INterfaces Service command line interface"""


@click.command()
@click.option(
    "--api-key",
    envvar='VINS_API_KEY',
    prompt="Enter VINS API key",
    help="VINS API key"
)
@click.option(
    "--vins-url",
    envvar='VINS_URL',
    prompt="Enter VINS url",
    help="VINS service url"
)
def init(api_key, vins_url):
    """initializes a new VINS environment by creating a Vinsfile"""

    import vins_cli.init

    try:
        vins_cli.init.command(api_key, vins_url)
    except VinsCfgParseError as e:
        click.secho('Error: %s !!!' % e.message, fg='red')
        exit(1)


@click.command()
def client():
    """connects to the server and tests the dialog"""

    import vins_cli.client

    try:
        vins_cli.client.command()
    except Exception as e:
        click.secho('Error: %s !!!' % e.message, fg='red')
        exit(1)


@click.command()
@click.option(
    "--force-register",
    is_flag=True,
    default=False,
    help="force register app_id and deploy"
)
def deploy(force_register):
    """deploy to the server"""

    import vins_cli.deploy

    try:
        vins_cli.deploy.command(force_register)
    except Exception as e:
        click.secho('Error: %s !!!' % e.message, fg='red')
        exit(1)


@click.command()
@click.option(
    "--add",
    help="add new intent"
)
def intent(add):
    """intent manipulations"""

    if add is not None:
        import vins_cli.intent.add
        try:
            vins_cli.intent.add.command(add)
        except Exception as e:
            click.secho('Error: %s !!!' % e.message, fg='red')
            exit(1)


def cli():
    main.add_command(init)
    main.add_command(client)
    main.add_command(deploy)
    main.add_command(intent)
    main(auto_envvar_prefix='VINSCLI')





import json
import os

import click
import requests

from vins_cli.exceptions import VinsCfgParseError
import vins_cli.settings as settings


def command(force_register):
    if force_register:
        click.secho('Registering a new application (force)...', fg='blue')

        with open(settings.VINS_CFG_PATH, "r") as f:
            cfg = json.load(f)

            if cfg.get('app') is None:
                raise VinsCfgParseError('"app" section is missing')
            if cfg.get('app').get('tokens') is None:
                raise VinsCfgParseError('"tokens" section is missing')

            api_key = cfg['app'].get('api_key')
            vins_url = cfg['app'].get('vins_url')
            app_id = cfg['app'].get('app_id')
            tokens = dict(
                admin=cfg['app']['tokens'].get('admin'),
                client=cfg['app']['tokens'].get('client')
            )

            if api_key is None:
                raise VinsCfgParseError('"api_key" is missing')
            if vins_url is None:
                raise VinsCfgParseError('"vins_url" is missing')
            if app_id is None:
                raise VinsCfgParseError('"app_id" is missing')
            if tokens['admin'] is None:
                raise VinsCfgParseError('"admin token" is missing')
            if tokens['client'] is None:
                raise VinsCfgParseError('"client token" is missing')

            register_app(api_key, vins_url, app_id, tokens)

            click.secho('Done!', fg='green')

    click.secho("Deploying...", fg='blue')

    if not os.path.exists(settings.VINS_CFG_PATH):
        raise VinsCfgParseError(
            "file %s does not exist" % settings.VINS_CFG_PATH
        )

    with open(settings.VINS_CFG_PATH, "r") as f:
        cfg = json.load(f)

        # - checking app section -

        if cfg.get('app') is None:
            raise VinsCfgParseError('"app" section is missing')
        if cfg.get('app').get('tokens') is None:
            raise VinsCfgParseError('"tokens" section is missing')

        api_key = cfg['app'].get('api_key')
        tokens = dict(
            admin=cfg['app']['tokens']['admin'],
            client=cfg['app']['tokens']['client']
        )
        vins_url = cfg['app'].get('vins_url')
        app_id = cfg['app'].get('app_id')

        # if api_key is None:
        #     raise VinsCfgParseError('"api_key" is missing')
        if tokens['admin'] is None:
            raise VinsCfgParseError('"admin token" is missing')
        if tokens['client'] is None:
            raise VinsCfgParseError('"client token" is missing')
        if vins_url is None:
            raise VinsCfgParseError('"vins_url" is missing')
        if app_id is None:
            raise VinsCfgParseError('"app_id" is missing')

        # - checking dm section -

        if cfg.get('dm') is None:
            raise VinsCfgParseError('"dm" section is missing')

        if cfg['dm'].get('intents') is None:
            raise VinsCfgParseError('"dm.intents" section is missing')

        if not isinstance(cfg['dm']['intents'], list):
            raise VinsCfgParseError('"dm.intents" must be a list')

        # - checking nlu section -

        if cfg.get('nlu') is None:
            raise VinsCfgParseError('"nlu" section is missing')

        if cfg['nlu'].get('intents') is None:
            raise VinsCfgParseError('"nlu.intents" section is missing')

        if not isinstance(cfg['nlu']['intents'], list):
            raise VinsCfgParseError('"nlu.intents" must be a list')

        # - checking nlg section -

        if cfg.get('nlg') is None:
            raise VinsCfgParseError('"nlg" section is missing')

        if cfg['nlg'].get('intents') is None:
            raise VinsCfgParseError('"nlg.intents" section is missing')

        if not isinstance(cfg['nlg']['intents'], list):
            raise VinsCfgParseError('"nlg.intents" must be a list')

        # - sending files -

        files = {
            'config': open(settings.VINS_CFG_PATH, 'rb')
        }

        for m in cfg['dm']['intents']:
            path = m['path']
            files[path] = open(path, 'rb')
        for m in cfg['nlu']['intents']:
            path = m['path']
            files[path] = open(path, 'rb')
        for m in cfg['nlg']['intents']:
            path = m['path']
            files[path] = open(path, 'rb')

        headers = {
            "x-vins-app-id": app_id,
            "x-vins-api-key": api_key,
            "x-vins-admin-token": tokens['admin']
        }

        r = requests.post(vins_url + "/deploy", files=files, headers=headers)
        if not r.ok:
            raise VinsCfgParseError(
                (
                    'deploy failed with error: %s' +
                    ' (http error code: %d) !'
                ) % (r.text, r.status_code)
            )

        # - done -

    click.secho("Done !", fg='green')


def register_app(api_key, vins_url, app_id, tokens):
    headers = {
        "x-vins-api-key": api_key,
        "x-vins-app-id": app_id,
        "x-vins-admin-token": tokens['admin'],
        "x-vins-client-token": tokens['client']
    }
    r = requests.get(vins_url + "/force_reg_app", headers=headers)
    if not r.ok:
        raise VinsCfgParseError(
            'application registration failed (force)' +
            ' (http error code: %d) !' % r.status_code,
        )




import json
import logging
import os
import readline

import click
import requests

from vins_cli.exceptions import VinsCfgParseError
import vins_cli.settings as settings


def command():
    uuid = get_random_uuid()

    if not os.path.exists(settings.VINS_CFG_PATH):
        raise VinsCfgParseError(
            "file %s does not exist" % settings.VINS_CFG_PATH
        )

    with open(settings.VINS_CFG_PATH, "r") as f:
        cfg = json.load(f)

        # - checking app section -

        if cfg.get('app') is None:
            raise VinsCfgParseError('"app" section is missing')

        if cfg.get('app').get('tokens') is None:
            raise VinsCfgParseError('"tokens" section is missing')

        token_client = cfg['app'].get('tokens').get('client')
        vins_url = cfg['app'].get('vins_url')
        app_id = cfg['app'].get('app_id')

        if token_client is None:
            raise VinsCfgParseError('"tokens->client" is missing')
        if vins_url is None:
            raise VinsCfgParseError('"vins_url" is missing')
        if app_id is None:
            raise VinsCfgParseError('"app_id" is missing')

    while True:
        utterance = raw_input(">>> ").decode('utf-8')
        if not utterance.strip():
            continue
        try:
            ans = vins_request(
                vins_url, app_id, token_client, uuid, utterance
            )

            for cmd in ans['commands']:
                if cmd['command'] == "say":
                    click.secho(cmd['text'], fg='red')
                if cmd['command'] == "device":
                    form = json.dumps(
                        cmd['form'], indent=2, ensure_ascii=False
                    )
                    click.secho(form, fg='green')
        except Exception as e:
            # logging.exception(e)
            raise


def vins_request(vins_url, app_id, token_client, uuid, utterance):
    js = {
        "utterance": utterance
    }
    js = json.dumps(js, indent=2, ensure_ascii=False)

    params = {
        'lang': 'ru-Ru',
        'uuid': uuid,
        'debug': 1
    }

    headers = {
        "x-vins-app-id": app_id,
        "x-vins-client-token": token_client
    }

    r = requests.post(
        vins_url + '/vins/json',
        params=params, data=dict(request=js), headers=headers
    )

    if not r.ok:
        raise Exception(
            (
                'connection failed with error: %s' +
                ' (http error code: %d) !'
            ) % (r.text, r.status_code)
        )

    return r.json()


def get_random_uuid():
    import random

    return ''.join(random.sample('1234567890abcdefg', 8))



from setuptools import setup, find_packages

setup(name='vins',
      version='1.0.11.0',
      description='Voice INterfaces Service CLI',
      author='Evgeny Volkov',
      author_email='wolf510@inbox.ru',
      packages = find_packages(),
      install_requires=['click', 'requests'],
      entry_points='''
          [console_scripts]
          vins=vins_cli:cli
      '''
)





import json
import os

import click
import requests

from vins_cli.exceptions import VinsCfgParseError
import vins_cli.settings as settings
from vins_cli.default import DEFAULT_VINS_CFG_FILE_TPL
from vins_cli.default import DEFAULT_INTENT_DONT_UNDERSTAND_TPL
from vins_cli.default import DEFAULT_INTENT_GOODBYE_TPL
from vins_cli.default import DEFAULT_INTENT_GREETING_TPL
from vins_cli.default import DEFAULT_INTENT_HOW_ARE_YOU_TPL
from vins_cli.default import DEFAULT_INTENT_THANKS_TPL
from vins_cli.default import DEFAULT_NLG_DONT_UNDERSTAND_TPL
from vins_cli.default import DEFAULT_NLG_GOODBYE_TPL
from vins_cli.default import DEFAULT_NLG_GREETING_TPL
from vins_cli.default import DEFAULT_NLG_HOW_ARE_YOU_TPL
from vins_cli.default import DEFAULT_NLG_THANKS_TPL
from vins_cli.default import DEFAULT_NLU_GOODBYE_TPL
from vins_cli.default import DEFAULT_NLU_GREETING_TPL
from vins_cli.default import DEFAULT_NLU_HOW_ARE_YOU_TPL
from vins_cli.default import DEFAULT_NLU_THANKS_TPL


def command(api_key, vins_url):
    click.secho('Registering a new application...', fg='blue')
    js = register_app(api_key, vins_url)

    click.secho('Making Vinsfile...', fg='blue')
    cfg = DEFAULT_VINS_CFG_FILE_TPL % dict(
        app_id=js['app_id'],
        token_admin=js['tokens']['admin'],
        token_client=js['tokens']['client'],
        api_key=api_key,
        vins_url=vins_url
    )
    cfg = json.loads(cfg)

    with open(settings.VINS_CFG_PATH, "w") as f:
        json.dump(cfg, f, indent=2, ensure_ascii=False)

    click.secho('Making subfolders...', fg='blue')

    os.mkdir('intents')
    os.mkdir('nlu')
    os.mkdir('nlg')

    click.secho('Making default commands...', fg='blue')

    with open("intents/dont_understand.js", "w") as f:
        f.write(DEFAULT_INTENT_DONT_UNDERSTAND_TPL)
    with open("intents/goodbye.js", "w") as f:
        f.write(DEFAULT_INTENT_GOODBYE_TPL)
    with open("intents/greeting.js", "w") as f:
        f.write(DEFAULT_INTENT_GREETING_TPL)
    with open("intents/how_are_you.js", "w") as f:
        f.write(DEFAULT_INTENT_HOW_ARE_YOU_TPL)
    with open("intents/thanks.js", "w") as f:
        f.write(DEFAULT_INTENT_THANKS_TPL)

    with open("nlg/dont_understand.nlg", "w") as f:
        f.write(DEFAULT_NLG_DONT_UNDERSTAND_TPL)
    with open("nlg/goodbye.nlg", "w") as f:
        f.write(DEFAULT_NLG_GOODBYE_TPL)
    with open("nlg/greeting.nlg", "w") as f:
        f.write(DEFAULT_NLG_GREETING_TPL)
    with open("nlg/how_are_you.nlg", "w") as f:
        f.write(DEFAULT_NLG_HOW_ARE_YOU_TPL)
    with open("nlg/thanks.nlg", "w") as f:
        f.write(DEFAULT_NLG_THANKS_TPL)

    with open("nlu/goodbye.nlu", "w") as f:
        f.write(DEFAULT_NLU_GOODBYE_TPL)
    with open("nlu/greeting.nlu", "w") as f:
        f.write(DEFAULT_NLU_GREETING_TPL)
    with open("nlu/how_are_you.nlu", "w") as f:
        f.write(DEFAULT_NLU_HOW_ARE_YOU_TPL)
    with open("nlu/thanks.nlu", "w") as f:
        f.write(DEFAULT_NLU_THANKS_TPL)

    click.secho("Done !", fg='green')


def register_app(api_key, vins_url):
    headers = {
        "x-vins-api-key": api_key
    }
    r = requests.get(vins_url + "/reg_app", headers=headers)
    if not r.ok:
        raise VinsCfgParseError(
            'application registration failed' +
            ' (http error code: %d) !' % r.status_code,
        )

    return r.json()
